﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Controls.Charts;

namespace DifferentLabelBasedOnZoomLevel
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            DataContext = ChartData.GenerateData(10000);
        }
    }

    public class RectWidthToLabelFormatConverter : IMultiValueConverter
    {
        public object Convert(object[] values, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            CategoryDateTimeXAxis axis = values[0] as CategoryDateTimeXAxis;
            XamDataChart chart = values[1] as XamDataChart;            
                
            var viewport = new Rect(0, 0,  axis.ActualWidth, chart.Axes.OfType<NumericYAxis>().First().ActualHeight);
            var window = chart.WindowRect;

            //Getting the minimum displayed datetime
            var minVal = axis.GetUnscaledValue(0, new ScalerParams(window, viewport, axis.IsInverted));
            DateTime min = new DateTime((long)minVal);
            //Getting the maximum displayed datetime
            var maxVal = axis.GetUnscaledValue(axis.ActualWidth, new ScalerParams(window, viewport, axis.IsInverted));
            DateTime max = new DateTime((long)maxVal);
            //Calculating the range, coverted by the axis
            TimeSpan axisRange = max - min;

            if (axisRange.Days > 0)
                return "{Date:dddd MMMM dd}";
            else
                return "{Date:T}"; 
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }


    public class ChartData
    {
        public DateTime Date { get; set; }
        public double Value1 { get; set; }
        public double Value2 { get; set; }
        public double Value3 { get; set; }

        public static ObservableCollection<ChartData> GenerateData(int count)
        {
            ObservableCollection<ChartData> data = new ObservableCollection<ChartData>();

            
            Random r = new Random();

            ChartData data0 = new ChartData
            {
                Date = DateTime.Now,
                Value1 = r.Next(20, 40),
                Value2 = r.Next(20, 40),
                Value3 = r.Next(20, 40),
            };

            data.Add(data0);

            for (int i = 1; i < count; i++)
            {
                ChartData dat = new ChartData
                {
                    Date = DateTime.Now.AddMinutes(i),
                };

                if (r.NextDouble() > .5)
                {
                    dat.Value1 = data[i - 1].Value1 + r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 + r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 + r.NextDouble();
                }
                else
                {
                    dat.Value1 = data[i - 1].Value1 - r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 - r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 - r.NextDouble();
                }

                data.Add(dat);
            }

            return data;
        }
    }
}
